==> skin.tetradui-1.3.5.zip: skin.tetradui/README.md <==
<p align="center">
<img src="https://github.com/gade01/skin.tetradui/blob/master/resources/clearlogo.png" width="400" align="middle">
</p>

# Tetrad [ te-trad ]
noun: a group or set of four

------------------------------------------------------------------------
## ABOUT TETRADUI 1.x FOR KODI 19 MATRIX
The aim with TetradUI is to create a fresh modern homage of the classic blades-style UI found in the original Xbox360 dashboard. Also seen in the works of Team Blackbolt and Jezz_X with projects MC360 and JX720 respectively. TetradUI is based from JX720 by Jezz_X.
  
Created by Jezz_X and TeamUI 
<br>

## DOCUMENTATION:
[Documentation for this skin can be found at the wiki](https://github.com/Ch3dd4rGoblin/skin.tetradui/wiki)  
<br>

## INSTALL:
TetradUI can be installed through [Gade's Development Repository](https://github.com/gade01/repository.gade/blob/master/leia/repository.gade/repository.gade-2.1.1.zip?raw=true).

To install this add-on you must do so from the Add-on manager from within Kodi by going to:   
1. Settings   
2. Add-ons   
3. Install from repository   
4. Gade's add-on repository   
5. Look and feel   
6. Skins   
7. TetradUI   
8. Install

Any script dependencies that the skin requires will automatically be downloaded. If you already have the skin file, then go into the add-ons node and choose "Install from zip file" and select the TetradUI zip file.

Manual installation of the skin can be done by moving the skin.tetradui folder inside the zip file into your addons folder of your Kodi profile.  
Please make sure you have the following scripts installed when doing it manually: 
  
script.embuary.helper v2.0.2  
<br>

## DEVELOPMENT REPOSITORY:  
By installing Gade's Development Repository you will always automatically receive the newest and freshest development updates of TetradUI and my other add-ons. You will still automatically get the official updates.  
To install this repository, you must do so by following these steps:  

1. [Download the zip file containing Gade's Add-on Repository from Github](https://github.com/gade01/repository.gade/raw/master/leia/repository.gade/repository.gade-2.1.1.zip)   
2. Start Kodi   
3. Navigate to settings   
4. Add-ons   
5. Install from zip file   
6. Locate the zip file you downloaded   
7. Install   

After this, you will automatically receive the latest development versions of TetradUI directly within Kodi.   

Recommended Kodi settings when installing the development repository:

- _Settings > System > Add-ons > Updates:_
<br>Install updates automatically   
- _Settings > System > Add-ons > Unknown sources:_
<br>Enabled   
- _Settings > System > Add-ons > Update official add-ons from:_
<br>Any repositories   
<br>

## DEVELOPMENT:
[Github](https://github.com/gade01/skin.tetradui)  
<br>

## LINKS:
[Kodi forum (skin support)](url placeholder) 

[SCREENSHOTS](url placeholder)  
<br>

## CREDITS: 
TeamUI:
[Gade](https://forum.kodi.tv/member.php?action=profile&uid=152411)
[Manfeed](https://forum.kodi.tv/member.php?action=profile&uid=81541)
[Ch3dd4rGoblin](https://forum.kodi.tv/member.php?action=profile&uid=465378)
<br>

## DONATIONS:
If you like TetradUI and want to show your appreciation, please make a donation.  
Any donation is greatly appreciated!

[![paypal](https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=TKBVTL8RFC43N&lc=DK&item_name=Gade&item_number=skin%2erapier&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_LG%2egif%3aNonHostedGuest)  
[![liberapay](https://liberapay.com/assets/widgets/donate.svg)](https://liberapay.com/Gade/donate)  
<br>

## LICENSE
This work is licensed under the Creative Commons Attribution-Share Alike 3.0 United States License.

To view a copy of this license, visit http://creativecommons.org/licenses/by-sa/3.0/us/ or send a letter to Creative Commons, 171 Second Street, Suite 300, San Francisco, California, 94105, USA.
<br>

==> skin.tetradui-2.0.0.zip: skin.tetradui/README.md <==
<p align="center">
<img src="https://github.com/gade01/skin.tetradui/blob/master/resources/clearlogo.png" width="400" align="middle">
</p>

# Tetrad [ te-trad ]
noun: a group or set of four

------------------------------------------------------------------------
## ABOUT TETRADUI 1.x FOR KODI 20 NEXUS
The aim with TetradUI is to create a fresh modern homage of the classic blades-style UI found in the original Xbox360 dashboard. Also seen in the works of Team Blackbolt and Jezz_X with projects MC360 and JX720 respectively. TetradUI is based from JX720 by Jezz_X.
  
Created by Jezz_X and TeamUI 
<br>

## DOCUMENTATION:
[Documentation for this skin can be found at the wiki](https://github.com/Ch3dd4rGoblin/skin.tetradui/wiki)  
<br>

## INSTALL:
TetradUI can be installed through the official Kodi repository or [Gade's Development Repository](https://github.com/gade01/repository.gade/blob/master/leia/repository.gade/repository.gade-2.1.1.zip?raw=true).

To install this add-on you must do so from the Add-on manager from within Kodi by going to:   
1. Settings   
2. Add-ons   
3. Install from repository   
4. Kodi add-on repository   
5. Look and feel   
6. Skins   
7. Rapier   
8. Install

Any script dependencies that the skin requires will automatically be downloaded. If you already have the skin file, then go into the add-ons node and choose "Install from zip file" and select the TetradUI zip file.

Manual installation of the skin can be done by moving the skin.tetradui folder inside the zip file into your addons folder of your Kodi profile.  
Please make sure you have the following scripts installed when doing it manually: 
  
script.embuary.helper v2.0.2  
<br>

## DEVELOPMENT REPOSITORY:  
By installing Gade's Development Repository you will always automatically receive the newest and freshest development updates of TetradUI and my other add-ons. You will still automatically get the official updates.  
To install this repository, you must do so by following these steps:  

1. [Download the zip file containing Gade's Add-on Repository from Github](https://github.com/gade01/repository.gade/raw/master/leia/repository.gade/repository.gade-2.1.1.zip)   
2. Start Kodi   
3. Navigate to settings   
4. Add-ons   
5. Install from zip file   
6. Locate the zip file you downloaded   
7. Install   

After this, you will automatically receive the latest development versions of TetradUI directly within Kodi.   

Recommended Kodi settings when installing the development repository:

- _Settings > System > Add-ons > Updates:_
<br>Install updates automatically   
- _Settings > System > Add-ons > Unknown sources:_
<br>Enabled   
- _Settings > System > Add-ons > Update official add-ons from:_
<br>Any repositories   
<br>

## DEVELOPMENT:
[Github](https://github.com/gade01/skin.tetradui)  
<br>

## LINKS:
[Kodi forum (skin support)](https://forum.kodi.tv/forumdisplay.php?fid=318) 

[Kodi Wiki](https://kodi.wiki/view/Add-on:TetradUI)

[SCREENSHOTS](url placeholder)  
<br>

## CREDITS: 
TeamUI:
[Gade](https://forum.kodi.tv/member.php?action=profile&uid=152411)
[Manfeed](https://forum.kodi.tv/member.php?action=profile&uid=81541)
[Ch3dd4rGoblin](https://forum.kodi.tv/member.php?action=profile&uid=465378)
<br>

## DONATIONS:
If you like TetradUI and want to show your appreciation, please make a donation.  
Any donation is greatly appreciated!

[![paypal](https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=TKBVTL8RFC43N&lc=DK&item_name=Gade&item_number=skin%2erapier&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_LG%2egif%3aNonHostedGuest)  
[![liberapay](https://liberapay.com/assets/widgets/donate.svg)](https://liberapay.com/Gade/donate)  
<br>

## LICENSE
This work is licensed under the Creative Commons Attribution-Share Alike 3.0 United States License.

To view a copy of this license, visit http://creativecommons.org/licenses/by-sa/3.0/us/ or send a letter to Creative Commons, 171 Second Street, Suite 300, San Francisco, California, 94105, USA.
<br>
